@@ -168,15 +168,13 @@ func readEnvConfig(envMap map[string]string) (Config, error) {
 // TODO: add better validation, more explicit default values and improve consistency between formats
 // TODO: accumulate all errors and differentiate between the layers?
 func getConsolidatedConfig(gs *state.GlobalState, cliConf Config, runnerOpts lib.Options) (conf Config, err error) {
-	// TODO: use errext.WithExitCodeIfNone(err, exitcodes.InvalidConfig) where it makes sense?
-
 	fileConf, err := readDiskConfig(gs)
 	if err != nil {
-		return conf, err
+		return conf, errext.WithExitCodeIfNone(err, exitcodes.InvalidConfig)
 	}
 	envConf, err := readEnvConfig(gs.Env)
 	if err != nil {
-		return conf, err
+		return conf, errext.WithExitCodeIfNone(err, exitcodes.InvalidConfig)
 	}
 
 	conf = cliConf.Apply(fileConf)
