@@ -112,7 +112,7 @@ func TestNewBundle(t *testing.T) {
 		t.Parallel()
 		_, err := getSimpleBundle(t, "/script.js", "\x00")
 		require.NotNil(t, err)
-		require.Contains(t, err.Error(), "SyntaxError: file:///script.js: Unexpected character '\x00' (1:0)\n> 1 | \x00\n")
+		require.Contains(t, err.Error(), "file:///script.js: Line 1:1 Unexpected token ILLEGAL (and 1 more errors)")
 	})
 	t.Run("Error", func(t *testing.T) {
 		t.Parallel()
@@ -124,7 +124,7 @@ func TestNewBundle(t *testing.T) {
 	t.Run("InvalidExports", func(t *testing.T) {
 		t.Parallel()
 		_, err := getSimpleBundle(t, "/script.js", `module.exports = null`)
-		require.EqualError(t, err, "exports must be an object")
+		require.EqualError(t, err, "GoError: CommonJS's exports must not be null\n") // TODO: try to remove the GoError from herer
 	})
 	t.Run("DefaultUndefined", func(t *testing.T) {
 		t.Parallel()
@@ -189,11 +189,6 @@ func TestNewBundle(t *testing.T) {
 					"InvalidCompat", "es1", `export default function() {};`,
 					`invalid compatibility mode "es1". Use: "extended", "base", "experimental_enhanced"`,
 				},
-				// ES2015 modules are not supported
-				{
-					"Modules", "base", `export default function() {};`,
-					"file:///script.js: Line 1:28 Unexpected reserved word (and 2 more errors)",
-				},
 				// BigInt is not supported
 				{
 					"BigInt", "base",
@@ -230,7 +225,7 @@ BigInt(1231412444)`,
 				Expr, Error string
 			}{
 				"Array":    {`[]`, "json: cannot unmarshal array into Go value of type lib.Options"},
-				"Function": {`function(){}`, "error parsing script options: json: unsupported type: func(goja.FunctionCall) goja.Value"},
+				"Function": {`function(){}`, "error parsing script options: json: unsupported type: func(sobek.FunctionCall) sobek.Value"},
 			}
 			for name, data := range invalidOptions {
 				t.Run(name, func(t *testing.T) {
@@ -532,7 +527,7 @@ func TestNewBundleFromArchive(t *testing.T) {
 
 		checkArchive(t, arc, lib.RuntimeOptions{}, "") // default options
 		checkArchive(t, arc, extCompatModeRtOpts, "")
-		checkArchive(t, arc, baseCompatModeRtOpts, "Unexpected reserved word")
+		checkArchive(t, arc, baseCompatModeRtOpts, "")
 	})
 
 	t.Run("es6_script_explicit", func(t *testing.T) {
@@ -543,7 +538,7 @@ func TestNewBundleFromArchive(t *testing.T) {
 
 		checkArchive(t, arc, lib.RuntimeOptions{}, "")
 		checkArchive(t, arc, extCompatModeRtOpts, "")
-		checkArchive(t, arc, baseCompatModeRtOpts, "Unexpected reserved word")
+		checkArchive(t, arc, baseCompatModeRtOpts, "")
 	})
 
 	t.Run("es5_script_with_extended", func(t *testing.T) {
@@ -568,13 +563,6 @@ func TestNewBundleFromArchive(t *testing.T) {
 		checkArchive(t, arc, baseCompatModeRtOpts, "")
 	})
 
-	t.Run("es6_archive_with_wrong_compat_mode", func(t *testing.T) {
-		t.Parallel()
-		arc, err := getArchive(t, es6Code, baseCompatModeRtOpts)
-		require.Error(t, err)
-		require.Nil(t, arc)
-	})
-
 	t.Run("messed_up_archive", func(t *testing.T) {
 		t.Parallel()
 		arc, err := getArchive(t, es6Code, extCompatModeRtOpts)
@@ -582,7 +570,7 @@ func TestNewBundleFromArchive(t *testing.T) {
 		arc.CompatibilityMode = "blah"                                           // intentionally break the archive
 		checkArchive(t, arc, lib.RuntimeOptions{}, "invalid compatibility mode") // fails when it uses the archive one
 		checkArchive(t, arc, extCompatModeRtOpts, "")                            // works when I force the compat mode
-		checkArchive(t, arc, baseCompatModeRtOpts, "Unexpected reserved word")   // failes because of ES6
+		checkArchive(t, arc, baseCompatModeRtOpts, "")                           // still works as even base compatibility supports ESM
 	})
 
 	t.Run("script_options_dont_overwrite_metadata", func(t *testing.T) {
