@@ -15,17 +15,15 @@ import (
 	"os"
 	"path"
 	"path/filepath"
-	"runtime"
 	"sort"
 	"strings"
 	"sync"
 	"testing"
 	"time"
 
-	"github.com/dop251/goja/parser"
 	"github.com/grafana/sobek"
+	"github.com/grafana/sobek/parser"
 	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 	"go.k6.io/k6/js/compiler"
 	"go.k6.io/k6/js/modules"
 	"go.k6.io/k6/js/modulestest"
@@ -60,7 +58,7 @@ var (
 		"top-level-await",             // not supported at all
 		"String.prototype.replaceAll", // not supported at all, Stage 4 since 2020
 
-		// from goja
+		// from Sobek
 		"Symbol.asyncIterator",
 		"regexp-named-groups",
 		"regexp-dotall",
@@ -71,9 +69,7 @@ var (
 		"tail-call-optimization",
 		"Temporal",
 		"import-assertions",
-		"dynamic-import",
 		"logical-assignment-operators",
-		"import.meta",
 		"Atomics",
 		"Atomics.waitAsync",
 		"FinalizationRegistry",
@@ -250,7 +246,6 @@ type tc39BenchmarkItem struct {
 type tc39BenchmarkData []tc39BenchmarkItem
 
 type tc39TestCtx struct {
-	compilerPool   *compiler.Pool
 	base           string
 	t              *testing.T
 	prgCache       map[string]*sobek.Program
@@ -412,11 +407,10 @@ func (ctx *tc39TestCtx) runTC39Test(t testing.TB, name, src string, meta *tc39Me
 		_ = vm.Set("print", t.Log)
 	}
 	var early bool
-	var origErr error
 	if meta.hasFlag("module") {
-		early, origErr, err = ctx.runTC39Module(name, src, meta.Includes, vm)
+		early, err = ctx.runTC39Module(name, src, meta.Includes, vm)
 	} else {
-		early, origErr, err = ctx.runTC39Script(name, src, meta.Includes, vm, meta.Negative.Type != "")
+		early, err = ctx.runTC39Script(name, src, meta.Includes, vm, meta.Negative.Type != "")
 	}
 
 	if err == nil {
@@ -447,9 +441,6 @@ func (ctx *tc39TestCtx) runTC39Test(t testing.TB, name, src string, meta *tc39Me
 	errType := getErrType(name, err, failf)
 
 	if errType != "" && errType != meta.Negative.Type {
-		if meta.Negative.Type == "SyntaxError" && origErr != nil && getErrType(name, origErr, failf) == meta.Negative.Type {
-			return
-		}
 		// vm.vm.prg.dumpCode(t.Logf)
 		failf("%s: unexpected error type (%s), expected (%s)", name, errType, meta.Negative.Type)
 		return
@@ -607,11 +598,7 @@ func (ctx *tc39TestCtx) compile(base, name string) (*sobek.Program, error) {
 			return nil, err
 		}
 
-		str := string(b)
-		comp := ctx.compilerPool.Get()
-		defer ctx.compilerPool.Put(comp)
-		comp.Options = compiler.Options{Strict: false, CompatibilityMode: ctx.compatibilityMode}
-		prg, _, err = comp.Compile(str, name, true)
+		prg, err = ctx.compileOnly(string(b), name, ctx.compatibilityMode)
 		if err != nil {
 			return nil, err
 		}
@@ -630,86 +617,83 @@ func (ctx *tc39TestCtx) runFile(base, name string, vm *sobek.Runtime) error {
 	return err
 }
 
-func (ctx *tc39TestCtx) runTC39Script(name, src string, includes []string, vm *sobek.Runtime, expectsError bool) (early bool, origErr, err error) {
+func (ctx *tc39TestCtx) compileOnly(src, name string, compatibilityMode lib.CompatibilityMode) (*sobek.Program, error) {
+	comp := ctx.compiler()
+	comp.Options = compiler.Options{CompatibilityMode: compatibilityMode}
+	astProgram, _, err := comp.Parse(src, name, false)
+	if err != nil {
+		return nil, err
+	}
+	return sobek.CompileAST(astProgram, false)
+}
+
+func (ctx *tc39TestCtx) compiler() *compiler.Compiler {
+	return compiler.New(testutils.NewLogger(ctx.t))
+}
+
+func (ctx *tc39TestCtx) runTC39Script(name, src string, includes []string, vm *sobek.Runtime, expectsError bool) (early bool, err error) {
 	early = true
 	err = ctx.runFile(ctx.base, path.Join("harness", "assert.js"), vm)
 	if err != nil {
-		return early, origErr, err
+		return early, err
 	}
 
 	err = ctx.runFile(ctx.base, path.Join("harness", "sta.js"), vm)
 	if err != nil {
-		return early, origErr, err
+		return early, err
 	}
 
 	for _, include := range includes {
 		err = ctx.runFile(ctx.base, path.Join("harness", include), vm)
 		if err != nil {
-			return early, origErr, err
+			return early, err
 		}
 	}
 
-	var p *sobek.Program
-	comp := ctx.compilerPool.Get()
-	defer ctx.compilerPool.Put(comp)
-	comp.Options = compiler.Options{Strict: false, CompatibilityMode: lib.CompatibilityModeBase}
-	p, _, err = comp.Compile(src, name, true)
-	origErr = err
+	p, err := ctx.compileOnly(src, name, lib.CompatibilityModeBase)
 	if err != nil && !expectsError {
-		comp.Options.CompatibilityMode = ctx.compatibilityMode
-		p, _, err = comp.Compile(src, name, true)
+		p, err = ctx.compileOnly(src, name, lib.CompatibilityModeExtended)
 	}
-
 	if err != nil {
-		return early, origErr, err
+		return early, err
 	}
 
 	early = false
 	_, err = vm.RunProgram(p)
 
-	return early, origErr, err
+	return early, err
 }
 
-func (ctx *tc39TestCtx) runTC39Module(name, src string, includes []string, vm *sobek.Runtime) (early bool, origErr, err error) {
-	currentFS := os.DirFS(".")
-	if err != nil {
-		panic(err)
-	}
+func (ctx *tc39TestCtx) runTC39Module(name, src string, includes []string, vm *sobek.Runtime) (early bool, err error) {
 	moduleRuntime := modulestest.NewRuntime(ctx.t)
 	moduleRuntime.VU.RuntimeField = vm
 	early = true
 	err = ctx.runFile(ctx.base, path.Join("harness", "assert.js"), vm)
 	if err != nil {
-		return early, origErr, err
+		return early, err
 	}
 
 	err = ctx.runFile(ctx.base, path.Join("harness", "sta.js"), vm)
 	if err != nil {
-		return early, origErr, err
+		return early, err
 	}
 
 	for _, include := range includes {
 		err = ctx.runFile(ctx.base, path.Join("harness", include), vm)
 		if err != nil {
-			return early, origErr, err
+			return early, err
 		}
 	}
 
-	comp := ctx.compilerPool.Get()
-	defer ctx.compilerPool.Put(comp)
-	comp.Options = compiler.Options{Strict: false, CompatibilityMode: ctx.compatibilityMode}
-
+	u := &url.URL{Scheme: "file", Path: "/" + path.Join(ctx.base, name)}
+	base := u.JoinPath("..")
 	mr := modules.NewModuleResolver(nil,
 		func(specifier *url.URL, _ string) ([]byte, error) {
-			return fs.ReadFile(currentFS, specifier.Path[1:])
+			return fs.ReadFile(os.DirFS("."), specifier.Path[1:])
 		},
-		comp)
-	u := &url.URL{Scheme: "file", Path: path.Join(ctx.base, name)}
+		ctx.compiler(), base)
 
-	base := u.JoinPath("..")
 	ms := modules.NewModuleSystem(mr, moduleRuntime.VU)
-	impl := modules.NewLegacyRequireImpl(moduleRuntime.VU, ms, *base)
-	require.NoError(ctx.t, vm.Set("require", impl.Require))
 	moduleRuntime.VU.InitEnvField.CWD = base
 
 	early = false
@@ -718,7 +702,7 @@ func (ctx *tc39TestCtx) runTC39Module(name, src string, includes []string, vm *s
 		URL:  u,
 	})
 
-	return early, origErr, err
+	return early, err
 }
 
 func (ctx *tc39TestCtx) runTC39Tests(name string) {
@@ -778,7 +762,6 @@ func runTestTC39(t *testing.T, compatibilityMode lib.CompatibilityMode) {
 
 	ctx := &tc39TestCtx{
 		base:              tc39BASE,
-		compilerPool:      compiler.NewPool(testutils.NewLogger(t), runtime.GOMAXPROCS(0)),
 		compatibilityMode: compatibilityMode,
 	}
 	ctx.init()
