@@ -62,10 +62,8 @@ func TestOldArchive(t *testing.T) {
 	t.Parallel()
 	testCases := map[string]string{
 		// map of filename to data for each main file tested
-		"github.com/k6io/k6/samples/example.js": `github file`,
-		"cdnjs.com/libraries/Faker":             `faker file`,
-		"C:/something/path2":                    `windows script`,
-		"/absolulte/path2":                      `unix script`,
+		"C:/something/path2": `windows script`,
+		"/absolulte/path2":   `unix script`,
 	}
 	for filename, data := range testCases {
 		filename, data := filename, data
@@ -74,20 +72,16 @@ func TestOldArchive(t *testing.T) {
 			metadata := `{"filename": "` + filename + `", "options": {}}`
 			fs := makeMemMapFs(t, map[string][]byte{
 				// files
-				"/files/github.com/k6io/k6/samples/example.js": []byte(`github file`),
-				"/files/cdnjs.com/libraries/Faker":             []byte(`faker file`),
-				"/files/example.com/path/to.js":                []byte(`example.com file`),
-				"/files/_/C/something/path":                    []byte(`windows file`),
-				"/files/_/absolulte/path":                      []byte(`unix file`),
+				"/files/example.com/path/to.js": []byte(`example.com file`),
+				"/files/_/C/something/path":     []byte(`windows file`),
+				"/files/_/absolulte/path":       []byte(`unix file`),
 
 				// scripts
-				"/scripts/github.com/k6io/k6/samples/example.js2": []byte(`github script`),
-				"/scripts/cdnjs.com/libraries/Faker2":             []byte(`faker script`),
-				"/scripts/example.com/path/too.js":                []byte(`example.com script`),
-				"/scripts/_/C/something/path2":                    []byte(`windows script`),
-				"/scripts/_/absolulte/path2":                      []byte(`unix script`),
-				"/data":                                           []byte(data),
-				"/metadata.json":                                  []byte(metadata),
+				"/scripts/example.com/path/too.js": []byte(`example.com script`),
+				"/scripts/_/C/something/path2":     []byte(`windows script`),
+				"/scripts/_/absolulte/path2":       []byte(`unix script`),
+				"/data":                            []byte(data),
+				"/metadata.json":                   []byte(metadata),
 			})
 
 			buf, err := dumpMemMapFsToBuf(fs)
@@ -101,12 +95,8 @@ func TestOldArchive(t *testing.T) {
 					"/absolulte/path2":    []byte(`unix script`),
 				}),
 				"https": makeMemMapFs(t, map[string][]byte{
-					"/example.com/path/to.js":                 []byte(`example.com file`),
-					"/example.com/path/too.js":                []byte(`example.com script`),
-					"/github.com/k6io/k6/samples/example.js":  []byte(`github file`),
-					"/cdnjs.com/libraries/Faker":              []byte(`faker file`),
-					"/github.com/k6io/k6/samples/example.js2": []byte(`github script`),
-					"/cdnjs.com/libraries/Faker2":             []byte(`faker script`),
+					"/example.com/path/to.js":  []byte(`example.com file`),
+					"/example.com/path/too.js": []byte(`example.com script`),
 				}),
 			}
 
@@ -146,16 +136,14 @@ func TestFilenamePwdResolve(t *testing.T) {
 			expectedPwdURL:      &url.URL{Scheme: "file", Path: "/home/nobody"},
 		},
 		{
-			Filename:            "github.com/k6io/k6/samples/http2.js",
-			Pwd:                 "github.com/k6io/k6/samples",
-			expectedFilenameURL: &url.URL{Opaque: "github.com/k6io/k6/samples/http2.js"},
-			expectedPwdURL:      &url.URL{Opaque: "github.com/k6io/k6/samples"},
+			Filename:      "github.com/k6io/k6/samples/http2.js",
+			Pwd:           "github.com/k6io/k6/samples",
+			expectedError: "are no longer supported",
 		},
 		{
-			Filename:            "cdnjs.com/libraries/Faker",
-			Pwd:                 "/home/nobody",
-			expectedFilenameURL: &url.URL{Opaque: "cdnjs.com/libraries/Faker"},
-			expectedPwdURL:      &url.URL{Scheme: "file", Path: "/home/nobody"},
+			Filename:      "cdnjs.com/libraries/Faker",
+			Pwd:           "/home/nobody",
+			expectedError: "are no longer supported",
 		},
 		{
 			Filename:            "https://example.com/something/dot.js",
